( cd sbin ; rm -rf rtstat )
( cd sbin ; ln -sf lnstat rtstat )
( cd sbin ; rm -rf ctstat )
( cd sbin ; ln -sf lnstat ctstat )
( cd usr/share/man/man8 ; rm -rf nstat.8.gz )
( cd usr/share/man/man8 ; ln -sf rtacct.8.gz nstat.8.gz )
( cd usr/share/man/man8 ; rm -rf tc-pfifo.8.gz )
( cd usr/share/man/man8 ; ln -sf tc-bfifo.8.gz tc-pfifo.8.gz )
( cd usr/share/man/man8 ; rm -rf ctstat.8.gz )
( cd usr/share/man/man8 ; ln -sf lnstat.8.gz ctstat.8.gz )
( cd usr/share/man/man8 ; rm -rf rtstat.8.gz )
( cd usr/share/man/man8 ; ln -sf lnstat.8.gz rtstat.8.gz )
( cd usr/share/man/man8 ; rm -rf routef.8.gz )
( cd usr/share/man/man8 ; ln -sf routel.8.gz routef.8.gz )
